pub struct MissionExecutor { /* private fields */ }Expand description
an executor calling a cargo (or similar) command in a separate thread when asked to and sending the lines of output in a channel, and finishing by None. Channel sizes are designed to avoid useless computations.
Implementations